@@ -54,7 +54,7 @@ class CloudConnection(_CloudMixin):
         if not x.isnumeric():
             print("invalid cloud var (not numeric):", value)
             raise(_exceptions.InvalidCloudValue)
-        while self._ratelimited_until + 0.11 > time.time():
+        while self._ratelimited_until + 0.1 >= time.time():
             pass
         try:
             self._send_packet(
@@ -73,7 +73,7 @@ class CloudConnection(_CloudMixin):
                 self._connect(cloud_host=self.cloud_host)
                 self._handshake()
 
-            time.sleep(0.11)
+            time.sleep(0.1)
             self.set_var(variable, value)
         self._ratelimited_until = time.time()
 
