@@ -13,6 +13,7 @@ class CloudRequests:
         self.requests = []
         self.current_var = 1
         self.ignore_exceptions = ignore_exceptions
+        self.idle_since = 0
 
     def request(self, function):
 
@@ -25,6 +26,10 @@ class CloudRequests:
 
     def _respond(self, request_id, response):
 
+        if self.idle_since + 8 < time.time():
+            self.connection._connect(cloud_host=None)
+            self.connection._handshake()
+
         remaining_response = str(response)
 
 
@@ -54,9 +59,15 @@ class CloudRequests:
                 remaining_response = ""
                 time.sleep(0.1)
 
+        self.idle_since = time.time()
+
+
 
 
     def run(self):
+        self.connection._connect(cloud_host=None)
+        self.connection._handshake()
+        self.idle_since = time.time()
         self.last_data = _cloud.get_cloud_logs(self.project_id, limit=100)
         self.last_timestamp = 0
         data = _cloud.get_cloud_logs(self.project_id, limit=100)
